RegisterInstanceRequest

Struct RegisterInstanceRequest 

pub struct RegisterInstanceRequest {
    pub instance_id: Option<String>,
}
Request for registering a notebook instance.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

instance_id: Option<String>

Required. User defined unique ID of this instance. The instance_id must be 1 to 63 characters long and contain only lowercase letters, numeric characters, and dashes. The first character must be a lowercase letter and the last character cannot be a dash.