pub struct ShieldedInstanceConfig {
pub enable_integrity_monitoring: Option<bool>,
pub enable_secure_boot: Option<bool>,
pub enable_vtpm: Option<bool>,
}Expand description
A set of Shielded Instance options. See Images using supported Shielded VM features. Not all combinations are valid.
This type is not used in any activity, and only used as part of another schema.
Fields
enable_integrity_monitoring: Option<bool>Defines whether the instance has integrity monitoring enabled. Enables monitoring and attestation of the boot integrity of the instance. The attestation is performed against the integrity policy baseline. This baseline is initially derived from the implicitly trusted boot image when the instance is created. Enabled by default.
enable_secure_boot: Option<bool>Defines whether the instance has Secure Boot enabled. Secure Boot helps ensure that the system only runs authentic software by verifying the digital signature of all boot components, and halting the boot process if signature verification fails. Disabled by default.
enable_vtpm: Option<bool>Defines whether the instance has the vTPM enabled. Enabled by default.